/* cbs_coloc.cpp
 *
 * Mex entry point for the function that builds the colocation matrix.
 * See cbs_coloc.m for documentation.
 *
 * History
 *  2011/06/24: First version
 *
 * Note
 *  CBS is partly based on the original source code of BBS.
 *
 * (c)2011, Florent Brunet.
 */
 
/* This file is part of CBS.
 *
 * CBS is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * CBS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CBS.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "cbs_mex.h"

/* prhs[0]: b-spline structure
 * prhs[1]: t
 * plhs[0]: (sparse) colocation matrix. */
void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[]) {
    cbs_t cbs;
    double *t = NULL;
    int nb_t;
    double *pr;
    mwIndex *ir, *jc;

    // INPUT ARGUMENTS
    if (nrhs != 2) 
        mexErrMsgTxt("Two input arguments are required.");
    
    // No need to check "prhs[0]" for validity since it is done in "array_to_cbs"
    array_to_cbs(prhs[0], &cbs);

    // Check t
    check_real(prhs[1], "t");
    nb_t = mxGetNumberOfElements(prhs[1]);

    t = mxGetPr(prhs[1]);
    
    
    // OUTPUT ARGUMENTS
    if (nlhs != 1) 
        mexErrMsgTxt("One output argument is required.");
    plhs[0] = mxCreateSparse(nb_t, cbs.npts, 4*nb_t, mxREAL);
    pr = mxGetPr(plhs[0]);
    ir = mxGetIr(plhs[0]);
    jc = mxGetJc(plhs[0]);
    
    // ACTUAL EVALUATION
    switch (coloc(&cbs, t, nb_t, pr, ir, jc)) {
        case 1: mexErrMsgTxt("A colocation site was outside of the spline definition domain.");
    }
}
