function mat = cbs_coloc_deriv(cbs, t, dt)
%cbs_coloc_deriv Build a colocation matrix with derivatives of the basis functions.
%
% mat = cbs_coloc_deriv(cbs, t, dt)
%
% Build the colocation matrix of the monodimensional B-Spline "cbs" for 
% the colocation sites t. Note that the colocation matrix is independant 
% of the dimension of the values of the spline. "cbs_coloc_deriv" is 
% similar to "cbs_coloc" except that this one is able to use derivatives 
% of the B-spline basis functions.
%
% INPUT ARGUMENTS
%
%   cbs: B-Spline structure (as created by cbs_create).
%
%   t [matrix]: Location used in the colocation matrix. This array
%   can be of any shape. Linear indexing is used to access its elements.
%
%   du [scalar]: order of derivation.
%
% OUTPUT ARGUMENTS
%
%   mat [(numel(u) x cbs.npts) sparse matrix]: colocation matrix. The
%   i-th row of "coloc" correspond to the site t(i).
%
% NOTE
%  CBS is partly based on the original source code of BBS.
%
% (c)2011, Florent Brunet.

% This file is part of CBS.
%
% CBS is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% CBS is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with CBS.  If not, see <http://www.gnu.org/licenses/>.
