function val = cbs_eval(cbs, ctrlpts, t, dt)
%cbs_eval Evaluate a monodimensional cubic B-Spline (or its derivatives).
%
% val = cbs_eval(cbs, ctrlpts, t)
% val = cbs_eval(cbs, ctrlpts, t, dt)
%
% Evaluate a monodimensional B-Spline at the locations contained in t.
%
% INPUT ARGUMENTS
%
%   cbs: B-Spline structure (as created by cbs_create).
%
%   ctrlpts [(valdim x npts) matrix]: control points of the B-Spline.
%
%   t [matrix]: Location where the B-Spline must be evaluated.
%
%   dt [optional, scalars]: Order of derivation.  Note that 
%   "cbs_eval(cbs, ctrlpts, t, 0)" is equivalent to 
%   "cbs_eval(cbs, ctrlpts, t)".
%
% OUTPUT ARGUMENTS
%
%   val [(valdim x numel(u)) matrix]: evaluation of the b-spline.
%   Note that t can be of any shape but that val is always of the
%   above-mentioned shape. Linear indexing is used to access u and v.
%   "val(:,i)" corresponds to (u(i),v(i)).
%
% NOTE
%  CBS is partly based on the original source code of BBS.
%
% (c)2011, Florent Brunet.

% This file is part of CBS.
%
% CBS is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% CBS is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with CBS.  If not, see <http://www.gnu.org/licenses/>.
